@@ -11,7 +11,7 @@ use Carp qw( carp croak );
 use Math::BigInt 1.97;
 our @ISA = qw(Math::BigInt);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Globals.
 
@@ -78,8 +78,11 @@ sub name {
     $lang = 'Math::BigInt::Named::' . ucfirst($lang);
 
     if (!defined $LOADED -> {$lang}) {
-        eval "require $lang;";
-        croak "Can't load module '$lang'" if $@;
+        my $file = $lang;
+        $file =~ s|::|/|g;
+        $file .= ".pm";
+        eval { require $file; };
+        croak $@ if $@;
         $LOADED -> {$lang} = 1;
     }
 
